#
# spec file for package libcgroup
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcgroup
%define lname	libcgroup1
Version:        0.41.rc1
Release:        1.10.1
Summary:        Control groups management tools
License:        LGPL-2.1-only
Group:          System/Management
Url:            http://sourceforge.net/projects/libcg/
Source:         http://sourceforge.net/projects/libcg/files/libcgroup/v0.41.rc/libcgroup-0.41.rc1.tar.bz2
Source3:        sysconfig.cgred
Source4:        cgconfig.service
Source99:       baselibs.conf
Patch6:         initd_cgred.patch
Patch9:         do-not-version-pam-module.patch
Patch10:        remove-initd_cgconfig.patch
Patch11:        0001-cgrulesengd-remove-umask-0.patch
Patch12:        0001-api.c-change-cgroup-of-every-thread-of-a-process.patch
Patch13:        0002-api.c-always-move-all-tasks-of-a-process-to-a-cgroup.patch
# 0001-cgrulesengd-Do-not-ignore-changes-of-short-lived-pro.patch (sent upstream)
Patch14:        0001-cgrulesengd-Do-not-ignore-changes-of-short-lived-pro.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
Requires:       pam
%{?systemd_requires}

%description
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package -n %lname
Summary:        Control groups management library
Group:          System/Libraries

%description -n %lname
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package devel
Summary:        Control groups management tools devel package
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%package tools
Summary:        Control groups management tools
# Added for openSUSE 12.3 to aid the solver.
Group:          System/Management
Provides:       libcgroup1:/usr/bin/cgexec
Requires(post):	%insserv_prereq %fillup_prereq
Requires:       insserv

%description tools
Control groups, a new kernel feature in Linux 2.6.24 provides a file
system interface to manipulate and control the details on task grouping
including creation of new task groups (control groups), permission
handling and task assignment.

%prep
%setup -n libcgroup-%{version}
%patch6 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1

%build
# only for GIT builds
%if 0
aclocal
libtoolize -c
autoconf
autoheader
automake --foreign --add-missing --copy
%endif
# ==============

autoreconf -f -i
%configure --enable-pam-module-dir=/%{_lib}/security --enable-initscript-install
export V=1
make %{?_smp_mflags}

%install
%makeinstall INITSCRIPTDIR=%{buildroot}/%{_sysconfdir}/init.d/
find $RPM_BUILD_ROOT -type f -name '*.la' -exec rm -f {} ';'
rm -f $RPM_BUILD_ROOT/%{_lib}/security/*.so.* 
mkdir -p %{buildroot}/usr/share/fillup-templates/
install -m 644 %{SOURCE3} %{buildroot}/usr/share/fillup-templates/sysconfig.cgred
%__install -D -m 444 %{SOURCE4} %{buildroot}%{_unitdir}/cgconfig.service

ln -s %{_sysconfdir}/init.d/cgred %{buildroot}/%{_sbindir}/rccgred
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rccgconfig

# remove setuid
chmod u-s $RPM_BUILD_ROOT/%{_bindir}/cgexec

# move lib to rootfs
libcgso=$(basename $RPM_BUILD_ROOT/%{_libdir}/libcgroup.so.*.*.*)
mkdir -p $RPM_BUILD_ROOT/%{_lib}
mv -f $RPM_BUILD_ROOT/%{_libdir}/libcgroup.so.*.*.* $RPM_BUILD_ROOT/%{_lib}
rm -f $RPM_BUILD_ROOT/%{_libdir}/libcgroup.so.1
ln -sf $libcgso $RPM_BUILD_ROOT/%{_lib}/libcgroup.so.1
ln -sf ../../%{_lib}/$libcgso $RPM_BUILD_ROOT/%{_libdir}/libcgroup.so

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%preun tools
%stop_on_removal cgred 
%service_del_preun cgconfig.service

%pre tools
%service_add_pre cgconfig.service

%post tools
%service_add_post cgconfig.service
%{fillup_and_insserv -n cgred}
test ! -e /var/log/cgred || chmod go-w /var/log/cgred
echo "cgconfig: WARNING: this version doesn't create /sysdefault cgroup"

%postun tools
%service_del_postun cgconfig.service
%restart_on_update cgred
%insserv_cleanup

%files -n %lname
%defattr(-,root,root)
/%{_lib}/libcgroup.so.*

%files tools
%defattr(-,root,root)
%doc COPYING
%doc README
%doc README_daemon
%doc samples/cgconfig.conf
%doc samples/cgrules.conf
%{_unitdir}/cgconfig.service
%{_sysconfdir}/init.d/cgred
%{_bindir}/cg*
%{_bindir}/ls*
%{_sbindir}/cg*
%{_sbindir}/rccgred
%{_sbindir}/rccgconfig
/%{_lib}/security/pam_cgroup.so
/usr/share/fillup-templates/sysconfig.cgred
%{_mandir}/man[^3]/*

%files devel
%defattr(-,root,root)
%{_libdir}/libcgroup.so
%{_includedir}/libcgroup.h
%dir %{_includedir}/libcgroup
%{_includedir}/libcgroup/*.h
%{_libdir}/pkgconfig/libcgroup.pc

%changelog
* Fri Mar 27 2020 mkoutny@suse.com
- drop libcgroup-new-sysconfigname.patch: rename sysconfig.libcgroup back to
  sysconfig.cgred (bsc#1166968)
* Fri Jun 14 2019 mkoutny@suse.com
- 0001-cgrulesengd-Do-not-ignore-changes-of-short-lived-pro.patch
  cgrulesengd: update to upstream version with fixup (bnc#1119100)
* Wed Apr 24 2019 mkoutny@suse.com
- 0001-api.c-change-cgroup-of-every-thread-of-a-process.patch:
- 0002-api.c-always-move-all-tasks-of-a-process-to-a-cgroup.patch:
  classify multithreaded processes (bnc#1119100)
- 0001-cgrulesengd-Do-not-ignore-changes-of-short-lived-pro.patch
  cgrulesengd: classify double-forking processes (bnc#1119100)
* Wed Aug 15 2018 mkoutny@suse.com
- Fix permissions of previously created log file
  (bnc#1100365, CVE-2018-14348)
* Wed Jul 25 2018 mhocko@suse.de
- 0001-cgrulesengd-remove-umask-0.patch: cgrulesengd: remove umask(0)
  (bnc#1100365, CVE-2018-14348)
* Fri Jul 15 2016 mkoutny@suse.com
- Don't interfere with systemd cgroup hierarchy (bnc#987985)
  * remove cgconfig-Do-not-overwrite-defaultcgroup-configuratio.patch
  * remove initd_cgconfig.patch
  * add remove-initd_cgconfig.patch
  * cgconfig init script replaced with .service file
* Wed Jan 14 2015 mhocko@suse.de
- cgconfig: Do not overwrite defaultcgroup configuration (bnc#912487)
* Tue Jan 13 2015 tcech@suse.cz
- add Require for post install scriptlets (bnc#912531)
* Fri Jan 10 2014 mhocko@suse.com
- package upgraded from 0.37 to 0.41.rc1
- libcgroup-man_pages.patch: removed because obsoleted by 41b1e43155831
- initd_cgconfig-read-correctly-defaultcgroup.patch: removed because
  obsoleted by 9659403b713f9
* Thu May  2 2013 mhocko@suse.cz
- do-not-version-pam-module.patch: fix an invalid link to pam_cgroup.so.0.0.0
  and do not build cgroup pam module as a versioned shared object (bnc#817533)
* Tue Nov 27 2012 jengelh@inai.de
- Remove redundant/obsolete sections from specfile
- Follow shlib packaging guidelines; libcgroup1 ought to only have
  the library, move the rest into libcgroup-tools.
* Thu Nov 22 2012 mhocko@suse.cz
- initd_cgconfig-read-correctly-defaultcgroup.patch: fix defaultcgroup
  detection (bnc#790934)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Oct 31 2011 jslaby@suse.de
- fix rpmlint warnings
* Wed Aug 31 2011 jslaby@suse.de
- don't use /var/lock/subsys/ (bnc#714631)
* Fri Jun 24 2011 jslaby@suse.de
- kill _service
* Wed May 11 2011 pth@suse.de
- Enhance the man pages.
* Thu Mar  3 2011 jslaby@suse.de
- update to 0.37.1
  - get rid of the local patches
  - fix buffer overflow (bnc#675506, CVE-2011-1006)
  - verify the sender of netlink messages (bnc#675048, CVE-2011-1022)
  - check length of netlink addresses (CVE-2011-1022)
  - improve handling of out-of-memory.
  - --sticky option works for setuid/setgid
* Wed Jan 12 2011 jslaby@suse.de
- sync cgconfig and cgred init.d scripts with upstream
- man pages fixes
* Tue Jan  4 2011 jslaby@suse.de
- update cgconfig and cgred init.d scripts
- fix segfault in cgconfigparser
* Mon Dec 20 2010 jslaby@suse.de
- update to 0.37
  - init scripts fixes
  - add new tools (scripts need not to do much work)
  - fixes in what tools and scripts return
  - many memory leaks fixed
  - other small fixes
* Mon Jul  5 2010 jslaby@suse.de
- update to 0.36.2 final
* Fri Jun  4 2010 kay.sievers@novell.com
- update to 0.36.2.rc
  - install pkg-config file
  - do not call exit() on error
- drop all patches which are upstream now or no longer needed
- install library in the rootfs, not in /usr
- enable verbose build
* Fri Feb  5 2010 jslaby@suse.de
- really fail to start (forgotten %%patch3)
* Thu Feb  4 2010 jslaby@suse.de
- fail to start when a parsing error occurs (bnc#576932)
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Aug 18 2009 jslaby@suse.de
- update init scripts. cgred moved to /usr/sbin/
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Mon May  4 2009 jslaby@suse.de
- update to 0.33
- refresh patches and make them -p1
- add pam module and manpages
* Fri Jan  2 2009 jslaby@suse.de
- Update to 0.32.2
- Fix devel package group (to Development/Libraries)
- Fix cgred init script
- Update cgconfig init script to create a default cgroup (bnc#458611)
* Wed Nov  5 2008 jslaby@suse.cz
- Update to 0.32.1
- Add init.d scripts configuration samples.
* Mon Oct 20 2008 schwab@suse.de
- Fix invalid use of sigaction.
* Wed Oct 15 2008 kukuk@suse.de
- Fix typo
* Tue Oct 14 2008 kukuk@suse.de
- Fix name of devel package
* Wed Oct  1 2008 jslaby@suse.cz
- initial package
